# -*- coding: utf-8 -*-
# Generated by Django 1.10.4 on 2017-03-15 09:28
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='CBRCurrency',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255, verbose_name='Name')),
                ('code', models.SlugField(unique=True)),
                ('num_code', models.SlugField()),
                ('char_code', models.SlugField()),
            ],
            options={
                'verbose_name_plural': 'Currencies',
                'verbose_name': 'Currency',
                'ordering': ['name'],
            },
        ),
        migrations.CreateModel(
            name='CBRCurrencyRate',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('date_rate', models.DateField(db_index=True, verbose_name='Date of rate')),
                ('nominal', models.PositiveSmallIntegerField(verbose_name='Nominal')),
                ('rate', models.DecimalField(decimal_places=4, max_digits=10, verbose_name='Rate')),
                ('currency', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='cbr.CBRCurrency', verbose_name='Currency')),
            ],
            options={
                'verbose_name_plural': 'Rates of currency',
                'verbose_name': 'Rate of currency',
                'ordering': ['date_rate'],
            },
        ),
    ]



from django import template

from cbr.models import CBRCurrencyRate

register = template.Library()


@register.inclusion_tag('cbr/informer.html', takes_context=True)
def currency_informer(context):
    usd = CBRCurrencyRate.objects.filter(currency__char_code='USD').last()
    eur = CBRCurrencyRate.objects.filter(currency__char_code='EUR').last()

    return {
        'request': context['request'],
        'usd': usd,
        'eur': eur,
    }



# -*- coding: utf-8 -*-
from django.contrib import admin

from .models import CBRCurrencyRate, CBRCurrency


class CBRCurrencyRateAdmin(admin.ModelAdmin):
    pass

admin.site.register(CBRCurrencyRate, CBRCurrencyRateAdmin)


class CBRCurrencyAdmin(admin.ModelAdmin):
    pass

admin.site.register(CBRCurrency, CBRCurrencyAdmin)



import requests
import xml.dom.minidom as minidom
from datetime import datetime
from decimal import Decimal

from django.core.management.base import BaseCommand

from cbr.models import CBRCurrency, CBRCurrencyRate


class Command(BaseCommand):
    def load_cbr(self):
        url = 'http://www.cbr.ru/scripts/XML_daily.asp'

        resp = requests.get(url)
        doc = minidom.parseString(resp.content.decode('cp1251'))

        # Date parsing
        valcurs = doc.getElementsByTagName('ValCurs')[0]
        date_rate = valcurs.attributes.get('Date').value
        date_rate = datetime.strptime(date_rate, '%d.%m.%Y')

        # Rate parsing
        valutes = doc.getElementsByTagName('Valute')
        for v in valutes:
            code = v.attributes.get('ID').value
            num_code = v.getElementsByTagName('NumCode')[0].childNodes[0].data
            char_code = v.getElementsByTagName('CharCode')[0].childNodes[0].data
            nominal = v.getElementsByTagName('Nominal')[0].childNodes[0].data
            name = v.getElementsByTagName('Name')[0].childNodes[0].data
            rate = v.getElementsByTagName('Value')[0].childNodes[0].data

            nominal = int(nominal)
            rate = Decimal(rate.replace(',', '.'))

            currency, created = CBRCurrency.objects.get_or_create(
                code=code, defaults={'name': name, 'num_code': num_code, 'char_code': char_code})

            try:
                change = CBRCurrencyRate.objects.filter(currency=currency).last().rate - rate
            except AttributeError:
                change = 0

            course, created = CBRCurrencyRate.objects.get_or_create(
                currency=currency, date_rate=date_rate, defaults={'nominal': nominal, 'rate': rate, 'change': change})

    def handle(self, *args, **options):
        self.load_cbr()



# -*- coding: utf-8 -*-
# Generated by Django 1.10.4 on 2017-08-29 05:27
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('cbr', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='cbrcurrencyrate',
            name='change',
            field=models.DecimalField(decimal_places=4, default=0, max_digits=10, verbose_name='Change'),
            preserve_default=False,
        ),
    ]



from django.db import models
from django.utils.translation import ugettext_lazy as _
from django.utils.encoding import python_2_unicode_compatible


@python_2_unicode_compatible
class CBRCurrency(models.Model):
    class Meta:
        verbose_name = _('Currency')
        verbose_name_plural = _('Currencies')
        ordering = ['name']

    def __str__(self):
        return self.name

    name = models.CharField(_('Name'), max_length=255)
    code = models.SlugField(unique=True)
    num_code = models.SlugField()
    char_code = models.SlugField()


@python_2_unicode_compatible
class CBRCurrencyRate(models.Model):
    class Meta:
        verbose_name = _('Rate of currency')
        verbose_name_plural = _('Rates of currency')
        ordering = ['date_rate']

    def __str__(self):
        return '{} - {}'.format(self.date_rate, self.rate)

    currency = models.ForeignKey(CBRCurrency, verbose_name=_('Currency'))
    date_rate = models.DateField(_('Date of rate'), db_index=True)
    nominal = models.PositiveSmallIntegerField(_('Nominal'))
    rate = models.DecimalField(_('Rate'), max_digits=10, decimal_places=4)
    change = models.DecimalField(_('Change'), max_digits=10, decimal_places=4)



import os
import sys

from setuptools import find_packages, setup

if sys.argv[-1] == 'publish':
    os.system('python setup.py sdist upload')
    sys.exit()

packages = find_packages()

setup(
    name='django-cbr',
    version='0.1.2',
    description='Load currencies rate from CBR site to Django model',
    long_description='Simply load currencies from Central Bank of Russia site (http://www.cbr.ru/scripts/XML_daily.asp) to Django model',
    author='Slava M',
    author_email='master@neucom.ru',
    url='https://github.com/slavama/django-cbr',
    packages=packages,
    include_package_data=True,
    py_modules=['cbr'],
    requires = ['python (>= 2.7)', 'django (>= 1.8)'],
    install_requires=[
        'requests>=2'
    ],
    license='MIT License',
    zip_safe=False,
    keywords='currency rate cbrf load',
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'Intended Audience :: Developers',
        'Natural Language :: English',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
    ]
)
